@@ -169,6 +169,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_ec2
@@ -192,8 +194,8 @@ class LambdaToSqsToLambda(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        consumer_lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        consumer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
         existing_consumer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
@@ -201,11 +203,11 @@ class LambdaToSqsToLambda(
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        producer_lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        producer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         queue_environment_variable_name: typing.Optional[builtins.str] = None,
-        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        sqs_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        sqs_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -228,6 +230,10 @@ class LambdaToSqsToLambda(
         :access: public
         :summary: Constructs a new instance of the LambdaToSqsToLambda class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaToSqsToLambda.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToSqsToLambdaProps(
             consumer_lambda_function_props=consumer_lambda_function_props,
             dead_letter_queue_props=dead_letter_queue_props,
@@ -247,27 +253,27 @@ class LambdaToSqsToLambda(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="consumerLambdaFunction")
     def consumer_lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "consumerLambdaFunction"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="producerLambdaFunction")
     def producer_lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "producerLambdaFunction"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="sqsQueue")
     def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
         return typing.cast(aws_cdk.aws_sqs.Queue, jsii.get(self, "sqsQueue"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="deadLetterQueue")
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
         return typing.cast(typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
         return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], jsii.get(self, "vpc"))
@@ -297,8 +303,8 @@ class LambdaToSqsToLambdaProps:
     def __init__(
         self,
         *,
-        consumer_lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        consumer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
         existing_consumer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
@@ -306,11 +312,11 @@ class LambdaToSqsToLambdaProps:
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        producer_lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        producer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         queue_environment_variable_name: typing.Optional[builtins.str] = None,
-        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        sqs_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        sqs_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param consumer_lambda_function_props: Optional user-provided properties to override the default properties for the consumer Lambda function. Default: - Default properties are used.
@@ -331,17 +337,33 @@ class LambdaToSqsToLambdaProps:
         :summary: The properties for the LambdaToSqsToLambda class.
         '''
         if isinstance(consumer_lambda_function_props, dict):
-            consumer_lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**consumer_lambda_function_props)
+            consumer_lambda_function_props = FunctionProps(**consumer_lambda_function_props)
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
+            dead_letter_queue_props = QueueProps(**dead_letter_queue_props)
         if isinstance(producer_lambda_function_props, dict):
-            producer_lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**producer_lambda_function_props)
+            producer_lambda_function_props = FunctionProps(**producer_lambda_function_props)
         if isinstance(queue_props, dict):
-            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
+            queue_props = QueueProps(**queue_props)
         if isinstance(sqs_event_source_props, dict):
-            sqs_event_source_props = aws_cdk.aws_lambda_event_sources.SqsEventSourceProps(**sqs_event_source_props)
+            sqs_event_source_props = SqsEventSourceProps(**sqs_event_source_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = VpcProps(**vpc_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaToSqsToLambdaProps.__init__)
+            check_type(argname="argument consumer_lambda_function_props", value=consumer_lambda_function_props, expected_type=type_hints["consumer_lambda_function_props"])
+            check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
+            check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
+            check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
+            check_type(argname="argument existing_consumer_lambda_obj", value=existing_consumer_lambda_obj, expected_type=type_hints["existing_consumer_lambda_obj"])
+            check_type(argname="argument existing_producer_lambda_obj", value=existing_producer_lambda_obj, expected_type=type_hints["existing_producer_lambda_obj"])
+            check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
+            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
+            check_type(argname="argument max_receive_count", value=max_receive_count, expected_type=type_hints["max_receive_count"])
+            check_type(argname="argument producer_lambda_function_props", value=producer_lambda_function_props, expected_type=type_hints["producer_lambda_function_props"])
+            check_type(argname="argument queue_environment_variable_name", value=queue_environment_variable_name, expected_type=type_hints["queue_environment_variable_name"])
+            check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
+            check_type(argname="argument sqs_event_source_props", value=sqs_event_source_props, expected_type=type_hints["sqs_event_source_props"])
+            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if consumer_lambda_function_props is not None:
             self._values["consumer_lambda_function_props"] = consumer_lambda_function_props
